@@ -8,10 +8,10 @@
 """
 from rest_framework.views import APIView
 
-from xj_thread.services.thread_item_service import ThreadItemService
-from xj_thread.utils.model_handle import parse_data, util_response
-from xj_thread.validator import ThreadAddValidator
 from xj_user.services.user_service import UserService
+from ..services.thread_item_service import ThreadItemService
+from ..utils.custom_response import util_response
+from ..utils.custom_tool import parse_data
 
 
 class ThreadAdd(APIView):
