@@ -6,12 +6,10 @@ Created on 2022-04-11
 from rest_framework.response import Response
 from rest_framework.views import APIView
 
-# from xj_user.utils.custom_authorization import CustomAuthentication
 from ..services.thread_category_tree_service import ThreadCategoryTreeServices
-from ..utils.model_handle import parse_data
-
-
-# from ..utils.custom_authentication_wrapper import authentication_wrapper
+from ..utils.custom_response import util_response
+from ..utils.custom_tool import parse_data
+from ..utils.user_wrapper import user_authentication_force_wrapper
 
 
 class ThreadCategoryTreeAPIView(APIView):
@@ -35,3 +33,14 @@ class ThreadCategoryTreeAPIView(APIView):
             return Response({'err': 1000, 'msg': error_text})
 
         return Response({'err': 0, 'msg': 'OK', 'data': category_serv})
+
+    # V2版本列别树
+    @user_authentication_force_wrapper
+    def get_category_tree_by_user(self, *args, user_info=None, **kwargs):
+        if user_info is None:
+            user_info = {}
+        user_id = user_info.get("user_id")
+        category_serv, error_text = ThreadCategoryTreeServices.get_category_tree_by_user(user_id=user_id)
+        if error_text:
+            return util_response(err=1000, msg=error_text)
+        return util_response(data=category_serv)
