@@ -8,7 +8,7 @@ from rest_framework.views import APIView
 
 # from xj_user.utils.custom_authorization import CustomAuthentication
 from ..services.thread_classify_tree_service import ThreadClassifyTreeServices
-from ..utils.model_handle import parse_data
+from ..utils.custom_tool import parse_data
 
 
 # from ..utils.custom_authentication_wrapper import authentication_wrapper
