@@ -10,9 +10,9 @@
 # 计数统计
 from rest_framework.views import APIView
 
-from xj_thread.services.thread_statistic_service import StatisticsService
-from xj_thread.utils.custom_response import util_response
-from xj_thread.utils.model_handle import parse_data
+from ..services.thread_statistic_service import StatisticsService
+from ..utils.custom_response import util_response
+from ..utils.custom_tool import parse_data
 
 
 class ThreadStaticAPIView(APIView):
