@@ -13,13 +13,13 @@ my_ip_addr = socket.gethostbyname(hostname)
 
 class ThreadShow(models.Model):
     """
-    2、Thread_ThreadShow 展示类型表
+    4、Thread_ThreadShow 展示类型表
     展示类型。用于对前端界面的显示样式进行分类
     """
 
     class Meta:
         db_table = 'thread_show'
-        verbose_name_plural = '13. 展示类型表 (样式)'
+        verbose_name_plural = '04. 展示类型表 (样式)'
 
     id = models.AutoField(verbose_name='展示类型ID', primary_key=True, help_text='')
     value = models.CharField(verbose_name='值', max_length=50, help_text='')
@@ -28,29 +28,29 @@ class ThreadShow(models.Model):
     description = models.CharField(verbose_name='描述', max_length=255, blank=True, null=True, help_text='')
 
     def __str__(self):
-        return f"{self.value}"
+        return f"{self.name} ({self.value or ''})"
 
 
 class ThreadCategory(models.Model):
     """
-    3、Thread_ThreadCategory 主类别表
+    2、Thread_ThreadCategory 主类别表
     类别。类似于版块大类的概念，用于圈定信息内容所属的主要类别
     """
 
     class Meta:
         db_table = 'thread_category'
-        verbose_name_plural = '11. 类别表 (页面类别)'
-        ordering = ["sort"]
+        verbose_name_plural = '02. 主类别表 (页面类别)'
+        # ordering = ['platform_code', 'parent_id__id', 'sort']
 
     id = models.AutoField(verbose_name='ID', primary_key=True, help_text='')
-    platform_code = models.IntegerField(verbose_name="平台码", blank=True, null=True, help_text='')
+    platform_code = models.CharField(verbose_name="平台码", max_length=16, blank=True, null=True, default="")
     value = models.CharField(verbose_name='值', max_length=50, help_text='')
     name = models.CharField(verbose_name='名称', max_length=255, blank=True, null=True, help_text='')
     need_auth = models.BooleanField(verbose_name="是否需要权限", blank=True, null=True, help_text='类别是否登录后才能查看')
     description = models.CharField(verbose_name='描述', max_length=255, blank=True, null=True, help_text='')
-    # parent_id = models.IntegerField(verbose_name='父类别ID', null=True, blank=True, help_text='')
     sort = models.IntegerField(verbose_name="排序", blank=True, null=True, help_text='默认排序为升序')
-    parent_id = models.ForeignKey(verbose_name='父类别ID', to='self', db_column='parent_id', related_name='+', on_delete=models.DO_NOTHING, blank=True, null=True, help_text='')
+    parent = models.ForeignKey(to="self", verbose_name='父类类别', db_column='parent_id', blank=True, null=True, help_text='', on_delete=models.DO_NOTHING)
+    is_deleted = models.BooleanField(verbose_name='是否删除', db_column="is_deleted", null=False, blank=True, help_text='')
 
     def short_description(self):
         if len(str(self.description)) > 30:
@@ -60,8 +60,7 @@ class ThreadCategory(models.Model):
     short_description.short_description = '描述'
 
     def __str__(self, help_text=''):
-        return f"{self.value}"
-
+        return f"{self.name} ({self.value or ''})"
 
     # 处理字段出现 前后空格问题
     def clean(self):
@@ -76,54 +75,51 @@ class ThreadCategory(models.Model):
 
 class ThreadClassify(models.Model):
     """
-    4、Thread_ThreadClassify 分类表
+    3、Thread_ThreadClassify 分类表
     @brief 分类。具体的分类，可以是按行业、兴趣、学科的分类，是主类别下的子分类。
     @note 考虑到多语言翻译的问题，不需要写接口，由运维在后台添加
     """
 
     class Meta:
         db_table = 'thread_classify'
-        verbose_name_plural = '12. 分类表 (行业分类)'
-        ordering = ["sort"]
+        verbose_name_plural = '03. 分类表 (行业分类)'
+        # ordering = ['category', 'parent_id__id', 'sort']  # TODO 不能在这里写排序，否则会导致所有查询都进行排序，会影响速度，所有已使用代码都要改掉 sieyoo by 20221105
 
     id = models.AutoField(verbose_name='分类ID', primary_key=True)
-    # key = models.CharField(verbose_name='分类关键字', max_length=50, blank=True, null=True, help_text='')
     value = models.CharField(verbose_name='分类', max_length=50, unique=True, help_text='')
     name = models.CharField(verbose_name='名称', max_length=255, blank=True, null=True, help_text='')
-    show = models.ForeignKey(verbose_name='默认展示ID', to=ThreadShow, db_column='show_id', related_name='+',
-                             on_delete=models.DO_NOTHING, null=True, blank=True, help_text='')
+    show = models.ForeignKey(verbose_name='默认展示ID', to=ThreadShow, db_column='show_id', related_name='+', on_delete=models.DO_NOTHING, null=True, blank=True, help_text='')
     description = models.CharField(verbose_name='描述', max_length=255, blank=True, null=True, help_text='')
-    category = models.ForeignKey(verbose_name='所属类别', to=ThreadCategory, db_column='category_id', related_name='+',
-                                 on_delete=models.DO_NOTHING, blank=True, null=True, help_text='')
+    category = models.ForeignKey(verbose_name='所属类别', to=ThreadCategory, db_column='category_id', related_name='+', on_delete=models.DO_NOTHING, blank=True, null=True, help_text='')
     icon = models.CharField(verbose_name='图标', max_length=255, blank=True, null=True, help_text='')
     sort = models.IntegerField(verbose_name="排序", blank=True, null=True, help_text='默认排序为升序')
-    parent_id = models.ForeignKey(verbose_name='父分类ID', to='self', db_column='parent_id', related_name='+', on_delete=models.DO_NOTHING, blank=True, null=True, help_text='')
+    parent = models.ForeignKey(to="self", verbose_name='父类分类', db_column='parent_id', blank=True, null=True, help_text='', on_delete=models.DO_NOTHING)
     config = models.JSONField(verbose_name='配置', blank=True, null=True, help_text='')
 
     def __str__(self, help_text=''):
-        return f"{self.value}"
+        return f"{self.name} ({self.value or ''})"
 
 
-# 访问权限。作者指定允许哪里用户可以访问，例如私有、公开、好友、指定某些人可以访问等。
-class ThreadAuth(models.Model):
-    class Meta:
-        db_table = 'thread_auth'
-        verbose_name_plural = '权限类型表'
-
-    id = models.AutoField(verbose_name='ID', primary_key=True)
-    value = models.CharField(verbose_name='值', max_length=50)
-
-    def __str__(self):
-        return f"{self.value}"
+# # 访问权限。作者指定允许哪里用户可以访问，例如私有、公开、好友、指定某些人可以访问等。
+# class ThreadAuth(models.Model):
+#     class Meta:
+#         db_table = 'thread_auth'
+#         verbose_name_plural = '权限类型表'
+#
+#     id = models.AutoField(verbose_name='ID', primary_key=True)
+#     value = models.CharField(verbose_name='值', max_length=50)
+#
+#     def __str__(self):
+#         return f"{self.value}"
 
 
 # 扩展字段数据表。用于扩展一些自定义的版块功能的数据
 class ThreadExtendData(models.Model):
-    """ 6、Thread_ThreadExtendData 扩展字段数据表 """
+    """ 5、Thread_ThreadExtendData 扩展字段数据表 """
 
     class Meta:
         db_table = 'thread_extend_data'
-        verbose_name_plural = '扩展字段数据表'
+        verbose_name_plural = '05. 扩展字段数据表'
 
     # id = models.AutoField(verbose_name='信息ID', primary_key=True, help_text='')
     thread_id = models.OneToOneField(verbose_name='信息ID', to='Thread', related_name="thread_extend_data", db_column='thread_id',
@@ -295,13 +291,13 @@ class ThreadExtendData(models.Model):
 
 # 扩展字段表。用于声明扩展字段数据表中的(有序)字段具体对应的什么键名。注意：扩展字段是对分类的扩展，而不是主类别的扩展
 class ThreadExtendField(models.Model):
-    """  7、Thread_ThreadExtendField 扩展字段表 """
+    """  6、Thread_ThreadExtendField 扩展字段表 """
 
     class Meta:
         db_table = 'thread_extend_field'
-        verbose_name_plural = '扩展字段表'
+        verbose_name_plural = '06. 扩展字段表'
         unique_together = (("category_id", "field"),)  # 组合唯一，分类+字段
-        ordering = ['-category_id']
+        # ordering = ['-category_id']
 
     field_index_choices = [
         ("field_1", "field_1"),
@@ -343,6 +339,12 @@ class ThreadExtendField(models.Model):
         ("image", "image"),
         ("switch", "switch"),
         ("cascader", "cascader"),
+        ("plain", "plain"),
+        ("textarea", "textarea"),
+        ("text", "text"),
+        ("number", "number"),
+        ("upload", "upload"),
+        ("password", "password"),
     ]
 
     id = models.AutoField(verbose_name='信息ID', primary_key=True, help_text='')
@@ -364,20 +366,18 @@ class Thread(models.Model):
     """  1、Thread_Thread 信息主表 """
 
     class Meta:
-        ordering = ['-create_time']
         db_table = 'thread'  # 指定数据库的表名，否则默认会显示app名+class名。
         verbose_name_plural = '01. 信息表'  # 指定管理界面的别名，否则默认显示class名。末尾不加s。
+        # ordering = ['-create_time']  # TODO 不能在模块设计中写排序，否则会导致所有查询都进行排序，会影响速度，尤其是这张表是大数据表，所有已使用代码都要改掉 sieyoo by 20221105
 
     bool_choice = [(0, '否'), (1, "是")]
     id = models.BigAutoField(verbose_name='ID', primary_key=True, help_text='')
     is_deleted = models.BooleanField(verbose_name='是否删除', blank=True, null=True, default=0, choices=bool_choice)
-    category_id = models.ForeignKey(verbose_name='类别ID', to=ThreadCategory, default=1, db_column='category_id', on_delete=models.DO_NOTHING, help_text='')
-    classify_id = models.ForeignKey(verbose_name='分类ID', to=ThreadClassify, db_column='classify_id', on_delete=models.DO_NOTHING, null=True, blank=True, help_text='')
-    show = models.ForeignKey(verbose_name='展示ID', to=ThreadShow, default=1, db_column='show_id', null=True, blank=True, on_delete=models.DO_NOTHING, related_name='+',
-                             help_text='如果没有传入显示类型，则使用分类表中的默认显示类型')  # 如果没有传入显示类型，则使用分类表中的默认显示类型
+    category = models.ForeignKey(verbose_name='类别ID', to=ThreadCategory, on_delete=models.DO_NOTHING, null=True, blank=True, help_text='')
+    classify = models.ForeignKey(verbose_name='分类ID', to=ThreadClassify, on_delete=models.DO_NOTHING, null=True, blank=True, help_text='')
+    show = models.ForeignKey(verbose_name='展示ID', to=ThreadShow, default=1, null=True, blank=True, on_delete=models.DO_NOTHING, related_name='+', help_text='如果没有传入显示类型，则使用分类表中的默认显示类型')  # 如果没有传入显示类型，则使用分类表中的默认显示类型
     user_id = models.BigIntegerField(verbose_name='用户ID', db_column='user_id', db_index=True, help_text='')
     with_user_id = models.BigIntegerField(verbose_name='与用户ID', db_column='with_user_id', blank=True, null=True, db_index=True, help_text='')
-    auth_id = models.ForeignKey(verbose_name='权限ID', to=ThreadAuth, db_column='auth_id', blank=True, null=True, related_name='+', on_delete=models.DO_NOTHING, help_text='')
     title = models.CharField(verbose_name='标题', max_length=255, blank=True, null=True, db_index=True, help_text='')
     subtitle = models.CharField(verbose_name='子标题', max_length=255, blank=True, null=True, db_index=True, help_text='')
     content = UEditorField(verbose_name='内容', blank=True, null=True, help_text='信息列表页是不返回内容字段的，因为这会增加数据的体积')
@@ -500,19 +500,19 @@ class ThreadStatistic(models.Model):
 
     class Meta:
         db_table = 'thread_statistic'
-        verbose_name = '信息统计表'
+        verbose_name = '10. 信息统计表'
         verbose_name_plural = verbose_name
 
 
 class ThreadTag(models.Model):
     """
-    8、Thread_ThreadTag 标签类型表
+    7、Thread_ThreadTag 标签类型表
     标签类型，存放预置标签。用于智能化推送信息，以及关键字检索。未来应设计成根据信息内容自动生成标签。
     """
 
     class Meta:
         db_table = 'thread_tag'
-        verbose_name_plural = '标签类型表'
+        verbose_name_plural = '07. 标签类型表'
 
     id = models.AutoField(verbose_name='ID', primary_key=True, help_text='')
     value = models.CharField(verbose_name='标签名', max_length=255, blank=True, null=True, help_text='')
@@ -524,12 +524,12 @@ class ThreadTag(models.Model):
 
 class ThreadTagMapping(models.Model):
     """
-    9、Thread_ThreadTagMapping 标签映射表
+    8、Thread_ThreadTagMapping 标签映射表
     标签映射，存放数据。即将标签和信息关联起来 """
 
     class Meta:
         db_table = 'thread_tag_mapping'
-        verbose_name_plural = '标签映射表'
+        verbose_name_plural = '08. 标签映射表'
 
     id = models.AutoField(verbose_name='ID', primary_key=True, help_text='')
     thread_id = models.ForeignKey(verbose_name='信息ID', to=Thread, db_column='thread_id', related_name='+', on_delete=models.DO_NOTHING, help_text='')
@@ -547,39 +547,38 @@ class ThreadImageAuth(models.Model):
 
     class Meta:
         db_table = 'thread_image_auth'
-        verbose_name_plural = '图片权限表'
+        verbose_name_plural = '09. 图片权限表'
 
     id = models.AutoField(verbose_name='ID', primary_key=True, help_text='')
     value = models.CharField(verbose_name='值', max_length=255, blank=True, null=True, help_text='')
 
-
-# 图片信息表。用于存放图片的各种信息，存放图片地址但不存放图。
-class ThreadResource(models.Model):
-    class Meta:
-        db_table = 'thread_resource'
-        verbose_name_plural = '图片表'
-
-    id = models.AutoField(verbose_name='ID', primary_key=True, help_text='')
-    name = models.CharField(verbose_name='图片名称', max_length=255, null=True, blank=True, help_text='')
-    url = models.CharField(verbose_name='图片链接', max_length=1024, null=True, blank=True, help_text='')
-    filename = models.CharField(verbose_name='文件名', max_length=255, null=True, blank=True, help_text='')
-    filetype = models.SmallIntegerField(verbose_name='文件类型', null=True, blank=True, help_text='')  # 文件类型0:图片，1:视频，2:文件
-    format = models.CharField(verbose_name='文件格式', max_length=50, help_text='')
-    image_auth_id = models.ForeignKey(verbose_name='图片权限ID', to=ThreadImageAuth, db_column='image_auth_id', related_name='+', on_delete=models.DO_NOTHING, null=True, blank=True, help_text='')
-    price = models.DecimalField(verbose_name='价格', max_digits=32, decimal_places=8, db_index=True, null=True, blank=True, help_text='')
-    snapshot = models.JSONField(verbose_name='快照', blank=True, null=True, help_text='')  # 存放图片的快照数据，如缩略图等。json对象
-    logs = models.JSONField(verbose_name='日志', blank=True, null=True, help_text='')  # 用于存放点击量，点赞量等,数组对象
-    # user_id = models.ForeignKey(verbose_name='用户ID', to=User, db_column='user_id', related_name='+', on_delete=models.DO_NOTHING)
-    user_id = models.BigIntegerField(verbose_name='用户ID', help_text='')
-    thread = models.ManyToManyField(to='Thread', through='ThreadToResource', through_fields=('resource_id', 'thread_id'), blank=True, help_text='')
+# # 图片信息表。用于存放图片的各种信息，存放图片地址但不存放图。
+# class ThreadResource(models.Model):
+#     class Meta:
+#         db_table = 'thread_resource'
+#         verbose_name_plural = '图片表'
+#
+#     id = models.AutoField(verbose_name='ID', primary_key=True, help_text='')
+#     name = models.CharField(verbose_name='图片名称', max_length=255, null=True, blank=True, help_text='')
+#     url = models.CharField(verbose_name='图片链接', max_length=1024, null=True, blank=True, help_text='')
+#     filename = models.CharField(verbose_name='文件名', max_length=255, null=True, blank=True, help_text='')
+#     filetype = models.SmallIntegerField(verbose_name='文件类型', null=True, blank=True, help_text='')  # 文件类型0:图片，1:视频，2:文件
+#     format = models.CharField(verbose_name='文件格式', max_length=50, help_text='')
+#     image_auth_id = models.ForeignKey(verbose_name='图片权限ID', to=ThreadImageAuth, db_column='image_auth_id', related_name='+', on_delete=models.DO_NOTHING, null=True, blank=True, help_text='')
+#     price = models.DecimalField(verbose_name='价格', max_digits=32, decimal_places=8, db_index=True, null=True, blank=True, help_text='')
+#     snapshot = models.JSONField(verbose_name='快照', blank=True, null=True, help_text='')  # 存放图片的快照数据，如缩略图等。json对象
+#     logs = models.JSONField(verbose_name='日志', blank=True, null=True, help_text='')  # 用于存放点击量，点赞量等,数组对象
+#     # user_id = models.ForeignKey(verbose_name='用户ID', to=User, db_column='user_id', related_name='+', on_delete=models.DO_NOTHING)
+#     user_id = models.BigIntegerField(verbose_name='用户ID', help_text='')
+#     thread = models.ManyToManyField(to='Thread', through='ThreadToResource', through_fields=('resource_id', 'thread_id'), blank=True, help_text='')
 
 
-# 标签映射，存放数据。即将标签和信息关联起来
-class ThreadToResource(models.Model):
-    class Meta:
-        db_table = 'thread_to_resource'
-        verbose_name_plural = '图文关联表'
-
-    id = models.AutoField(verbose_name='ID', primary_key=True, help_text='')
-    thread_id = models.ForeignKey(verbose_name='信息ID', to=Thread, db_column='thread_id', related_name='+', on_delete=models.DO_NOTHING, help_text='')
-    resource_id = models.ForeignKey(verbose_name='图片ID', to=ThreadResource, db_column='resource_id', related_name='+', on_delete=models.DO_NOTHING, help_text='')
+# # 标签映射，存放数据。即将标签和信息关联起来
+# class ThreadToResource(models.Model):
+#     class Meta:
+#         db_table = 'thread_to_resource'
+#         verbose_name_plural = '图文关联表'
+#
+#     id = models.AutoField(verbose_name='ID', primary_key=True, help_text='')
+#     thread_id = models.ForeignKey(verbose_name='信息ID', to=Thread, db_column='thread_id', related_name='+', on_delete=models.DO_NOTHING, help_text='')
+#     resource_id = models.ForeignKey(verbose_name='图片ID', to=ThreadResource, db_column='resource_id', related_name='+', on_delete=models.DO_NOTHING, help_text='')
