@@ -11,7 +11,6 @@ from xj_user.models import BaseInfo, DetailInfo
 from .models import (ThreadShow,
                      ThreadClassify,
                      ThreadCategory,
-                     ThreadAuth,
                      Thread,
                      ThreadStatistic,
                      ThreadTag,
@@ -65,16 +64,16 @@ class ThreadCategoryListSerializer(serializers.ModelSerializer):
         return str(getattr(instance, "value", ""))
 
 
-class ThreadAuthListSerializer(serializers.ModelSerializer):
-    """访问权限序列化"""
-    label = serializers.SerializerMethodField()
-
-    class Meta:
-        model = ThreadAuth
-        fields = ("id", "label")
-
-    def get_label(self, instance):
-        return tr(instance.value)
+# class ThreadAuthListSerializer(serializers.ModelSerializer):
+#     """访问权限序列化"""
+#     label = serializers.SerializerMethodField()
+#
+#     class Meta:
+#         model = ThreadAuth
+#         fields = ("id", "label")
+#
+#     def get_label(self, instance):
+#         return tr(instance.value)
 
 
 class ThreadStatisticListSerializer(serializers.ModelSerializer):
@@ -173,17 +172,17 @@ class ThreadListSerializer(serializers.ModelSerializer):
         show_value = instance.show_id.value if instance.show_id else None
         return show_value
 
-    def get_auth_value(self, instance):
-        auth_value = instance.auth_id.value if instance.auth_id else None
-        return auth_value
+    # def get_auth_value(self, instance):
+    #     auth_value = instance.auth_id.value if instance.auth_id else None
+    #     return auth_value
 
     def get_classify_label(self, instance):
         classify_value = tr(instance.classify_id.value) if instance.classify_id else None
         return classify_value
 
-    def get_auth_label(self, instance):
-        auth_value = tr(instance.auth_id.value) if instance.auth_id else None
-        return auth_value
+    # def get_auth_label(self, instance):
+    #     auth_value = tr(instance.auth_id.value) if instance.auth_id else None
+    #     return auth_value
 
     def get_thread_extends(self, instance):
         if not hasattr(instance, 'thread_extend_data'):
@@ -200,9 +199,9 @@ class ThreadDetailSerializer(serializers.ModelSerializer):
     category_value = serializers.SerializerMethodField()
     classify_value = serializers.SerializerMethodField()
     show_value = serializers.SerializerMethodField()
-    auth_value = serializers.SerializerMethodField()
+    # auth_value = serializers.SerializerMethodField()
     show_label = serializers.SerializerMethodField()
-    auth_label = serializers.SerializerMethodField()
+    # auth_label = serializers.SerializerMethodField()
     full_name = serializers.SerializerMethodField()
     user_name = serializers.SerializerMethodField()
     nickname = serializers.SerializerMethodField()
@@ -232,23 +231,23 @@ class ThreadDetailSerializer(serializers.ModelSerializer):
 
     @catch_except
     def get_show_value(self, instance):
-        show_value = instance.show_id.value if instance.show_id else None
+        show_value = instance.show.value if instance.show_id else None
         return show_value
 
-    @catch_except
-    def get_auth_value(self, instance):
-        auth_value = instance.auth_id.value if instance.auth_id else None
-        return auth_value
+    # @catch_except
+    # def get_auth_value(self, instance):
+    #     auth_value = instance.auth.value if instance.auth_id else None
+    #     return auth_value
 
     @catch_except
     def get_show_label(self, instance):
-        show_value = tr(instance.show_id.value) if instance.show_id else None
+        show_value = tr(instance.show.value) if instance.show_id else None
         return show_value
 
-    @catch_except
-    def get_auth_label(self, instance):
-        auth_value = tr(instance.auth_id.value) if instance.auth_id else None
-        return auth_value
+    # # @catch_except
+    # def get_auth_label(self, instance):
+    #     auth_value = tr(instance.auth_id.value) if instance.auth_id else None
+    #     return auth_value
 
     @catch_except
     def get_full_name(self, instance):
@@ -284,5 +283,6 @@ class ThreadDetailSerializer(serializers.ModelSerializer):
     def get_thread_extends(self, instance):
         if not hasattr(instance, 'thread_extend_data'):
             return {}
-        fields = ThreadExtendField.objects.filter(category_id=instance.category_id.id)
+        print("instance.category:",instance)
+        fields = ThreadExtendField.objects.filter(category_id=instance.category.id)
         return {field.field: getattr(instance.thread_extend_data, field.field_index, None) for field in fields}
