@@ -53,7 +53,7 @@ class ThreadExtendInputService:
 class ThreadExtendOutPutService():
     # extend_field:扩展数据表的字段如field_1,field_2....
     # field:配置的字段映射
-    filed_list = None
+    field_list = None
     extend_field_map = None  # {extend_field:field}
     field_map = None  # {field:extend_field}
     finish_data = None  # 最终完成映射的扩展数据字典
@@ -67,13 +67,16 @@ class ThreadExtendOutPutService():
         self.thread_id_list = thread_id_list
 
         # 字段映射关系
-        self.filed_list = ThreadExtendField.objects.filter(category_id__in=self.category_id_list).to_json()
-        self.filed_map = {}  # {i["category_id"]: {i["field_index"]: i["field"],....},....}
-        for item in self.filed_list:
-            if self.filed_map.get(item["category_id_id"]):
-                self.filed_map[item["category_id_id"]].update({item["field_index"]: item["field"]})
+        field_list_set = ThreadExtendField.objects.filter(category_id__in=self.category_id_list)
+        self.field_list = []
+        if field_list_set:
+            self.field_list = list(field_list_set.values())
+        self.field_map = {}  # {i["category_id"]: {i["field_index"]: i["field"],....},....}
+        for item in self.field_list:
+            if self.field_map.get(item["category_id"]):
+                self.field_map[item["category_id"]].update({item["field_index"]: item["field"]})
             else:
-                self.filed_map[item["category_id_id"]] = {item["field_index"]: item["field"]}
+                self.field_map[item["category_id"]] = {item["field_index"]: item["field"]}
 
     def out_put(self):
         self.finish_data = {}  # 返回 self.finish_data：{thread_id:{扩展数据},.....} {thread_id:{扩展数据},.....}
@@ -82,7 +85,7 @@ class ThreadExtendOutPutService():
         extend_data = [(i.pop("thread_id_id"), i.pop("category_id"), i) for i in extend_data]
         # 扩展数据 替换KEY
         for thread_id, category_id, item in extend_data:
-            category_field = self.filed_map.get(category_id, None)
+            category_field = self.field_map.get(category_id, None)
             if category_field is None:
                 continue
             remove_none = {k: v for k, v in item.items() if v}
@@ -112,13 +115,15 @@ class ThreadExtendService:
         if thread_id is None:
             return None, "扩展字段修改错误,thread_id不可以为空"
         # 获取扩展字段映射
-        category = Thread.objects.filter(id=thread_id).first()
-        if not category and not category_id:
+        thread_obj = Thread.objects.filter(id=thread_id).first()
+        if not thread_obj and not category_id:
             return None, None
-        category_id = category_id if category_id else category.category_id
-        extend_fields = ThreadExtendField.objects.filter(category_id_id=category_id).values("field_index", "field")
+        category_id = category_id if category_id else thread_obj.category_id
+        # 扩展字段映射
+        extend_fields = ThreadExtendField.objects.filter(category_id=category_id).values("field_index", "field")
         extend_field_map = {item["field"]: item["field_index"] for item in extend_fields}
-        transformed_extend_params = {extend_field_map[k]: v for k, v in extend_params.items() if k in extend_field_map.keys()}
+        # 扩展数据替换
+        transformed_extend_params = {extend_field_map[k]: v for k, v in extend_params.items() if extend_field_map.get(k)}
         # 修改或添加数据
         try:
             extend_obj = ThreadExtendData.objects.filter(thread_id=thread_id)
